@@ -1,16 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Privat",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "Vizibil doar pentru persoanele care se potrivesc prin integrarea numărului de telefon prin Talk pe mobil",
-    "Local" : "Local",
-    "Only visible to people on this instance and guests" : "Vizibil doar pentru persoanele din această instanță și pentru oaspeți",
-    "Federated" : "Federat",
-    "Only synchronize to trusted servers" : "Sincronizează doar cu serverele de încredere",
-    "Published" : "Publicat",
-    "Synchronize to trusted servers and the global and public address book" : "Sincronizarea cu serverele de încredere și cu cartea de adrese globală și publică",
-    "Verify" : "Verifică",
-    "Verifying …" : "Se verifică ...",
     "Unable to change password" : "Imposibil de schimbat parola",
     "Very weak password" : "Parolă foarte slabă",
     "Weak password" : "Parolă slabă",
@@ -48,18 +38,12 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "Ștergerea de la distanță a fost pornită pe %1$s",
     "Remote wipe has finished on %1$s" : "Ștergerea de la distanță s-a încheiat pe %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>Parola </strong> sau <strong>mailul </strong>a fost modificat",
-    "Apps" : "Aplicații",
+    "Settings" : "Setări",
     "Wrong password" : "Parolă greșită",
     "Unable to change personal password" : "Nu se poate schimba parola personală",
     "Saved" : "Salvat",
-    "No user supplied" : "Nu a fost furnizat niciun utilizator",
     "Authentication error" : "Eroare la autentificare",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Furnizează o parolă administrativă de recuperare, altfel toate datele utilizatorilor vor fi pierdute",
     "Wrong admin recovery password. Please check the password and try again." : "Parolă administrativă de recuperare greșită. Verifică parola și încearcă din nou.",
-    "installing and updating apps via the App Store or Federated Cloud Sharing" : "instalarea și actualizarea aplicațiilor prin intermediul App Store sau Federated Cloud Sharing",
-    "Federated Cloud Sharing" : "Partajare federalizată cloud",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL utilizează o versiune %1$sneupdatată (%2$s). Vă rugăm să updatați sistemul de operare sau actualizați caracteristicile %3$scare nu funcționează în mod fiabil.",
-    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "Modulul PHP OPcache nu este încărcat. Pentru o performanță mai bună, se recomandă să îl încărcați în instalarea PHP.",
     "Administrator documentation" : "Documentație pentru administrare",
     "User documentation" : "Documentație utilizator",
     "Invalid SMTP password." : "Parolă SMTP invalidă.",
@@ -68,8 +52,6 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "Daca primești acest mail, configurările de email au fost efectuate corect.",
     "Email could not be sent. Check your mail server log" : "Mesajul nu a putut fi trimis. Verifică logul serverului de mail.",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : " A apărut o problemă la trimiterea emailului. Verifică-ți setărie. (Eroare: %s)",
-    "Users" : "Utilizatori",
-    "Invalid user" : "Utilizator invalid",
     "Invalid mail address" : "Adresa mail invalidă",
     "Settings saved" : "Setările au fost salvate",
     "Unable to change full name" : "Nu s-a putut schimba numele complet",
@@ -90,14 +72,15 @@ OC.L10N.register(
     "Your %s account was created" : "Contul tău %s a fost creat",
     "Welcome aboard" : "Bun venit la bord",
     "Welcome aboard %s" : "Bun venit la bord %s",
-    "Your username is: %s" : "Utilizatorul tău este: %s",
     "Set your password" : "Setează parola",
+    "Go to %s" : "Salt la %s",
     "Install Client" : "Instalează client",
-    "Logged in user must be a subadmin" : "Utilizatorul logat trebuie să fie un subadmin",
-    "Settings" : "Setări",
+    "Apps" : "Aplicații",
     "Personal" : "Personal",
     "Administration" : "Administrare",
+    "Users" : "Utilizatori",
     "Additional settings" : "Setări adiționale",
+    "Assistant" : "Asistent",
     "Administration privileges" : "Privilegii de administrare",
     "Groupware" : "Articole de grup",
     "Overview" : "Prezentare generală",
@@ -107,26 +90,38 @@ OC.L10N.register(
     "Personal info" : "Informații personale",
     "Mobile & desktop" : "Mobil și desktop",
     "Email server" : "Server de email",
-    "Security & setup warnings" : "Alerte de securitate & configurare",
     "Background jobs" : "Proces de fundal",
-    "Create" : "Creează",
-    "Change" : "Schimbă",
-    "Delete" : "Șterge",
-    "Reshare" : "Redistribuiți",
     "Unlimited" : "Nelimitată",
     "Verifying" : "Se verifică",
-    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Este în așteptare o sarcină de lucru în fundal care verifică dacă există certificate SSL importate de utilizator. Vă rugăm să reveniți mai târziu.",
-    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Sunt prezente unele certificate SSL importate de utilizator, care nu mai sunt utilizate cu Nextcloud 21. Acestea pot fi importate în linia de comandă prin intermediul comenzii \"occ security:certificates:import\". Căile lor în interiorul directorului de date sunt prezentate mai jos.",
-    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Au fost găsite UUID-uri nevalabile ale utilizatorilor sau grupurilor LDAP. Vă rugăm să revizuiți setările \"Override UUID detection\" din partea Expert a configurației LDAP și să utilizați \"occ ldap:update-uuid\" pentru a le actualiza.",
+    "Verifying …" : "Se verifică ...",
+    "Verify" : "Verifică",
+    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Directorul de date și fișierele sunt probabil accesibile din Internet. Fișierul .htaccess nu este funcțional. Se recomandă puternic configurarea serverului web astfel încât directorul de date să nu mai fie accesibil astfel, sau mutați-l în afara rădăcinii documentelor a serverului web.",
+    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Lipsesc coloane opționale din baza de date. Datorită faptului că adăugarea de coloane tabelelor mari durează mult, acestea nu au fost adăugate automat atunci când pot fi opționale. Rulând \"occ db:add-missing-columns\", aceste coloane lipsă pot fi adăugate manual în timp ce instanța este online. Odată ce aceste coloane opționale au fost adăugate, unele funcționalități pot îmbunătăți timpul de răspuns sau uzabilitatea. ",
+    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Bazei de date îi lipsesc câteva chei primare. Datorită faptului că adăugarea cheilor primare la tabelele mari durează mult, acestea nu au fost adăugate automat. Rulând \"occ db:add-missing-primary-keys\", aceste chei primare lipsă pot fi adăugate manual în timp ce instanța rulează. ",
+    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Instanța este în modul debug. Folosiți aceasta doar pentru dezvoltare și nu în producție.",
+    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Acest server nu are o conexiune funcțională la Internet. Mai multe puncte finale nu pot fi contactate. Aceasta înseamnă că unele funcționalități precum montarea unui spațiu extern de stocare, notificări despre actualizări sau instalarea aplicațiilor din sursă terță nu vor fi accesibile. De asemenea, ar putea să nu funcționeze nici accesarea fișierelor la distanță și transmiterea emailurilor de notificare .",
+    "Disabled" : "Dezactivați",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "Este activat vechiul format de criptare din partea serverului. Vă recomandăm să dezactivați acest lucru.",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Funcția PHP \"set_time_limit\" nu este disponibilă. Aceasta ar putea avea ca efect ca scripturile să fie oprite în timpul execuției, compromițând instalarea. Se recomandă puternic activarea acestei funcții.",
+    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Instalarea PHP nu are suport pentru FreeType, introducând incompatibilități cu imaginile de profil și cu interfața de configurare.",
+    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP nu pare să fie configurat corespunzător pentru a interoga variabilele de mediu ale sistemului. Testul cu getenv(\"PATH\") returnează doar un răspuns gol.",
+    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "Modulul PHP OPcache nu este încărcat. Pentru o performanță mai bună, se recomandă să îl încărcați în instalarea PHP.",
+    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "A fost activată configurația doar pentru citire. Acest lucru împiedică setarea unor configurații prin intermediul interfeței web. În plus, fișierul trebuie să fie făcut scriere manual la fiecare actualizare.",
+    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Baza dumneavoastră de date nu rulează cu nivelul de izolare a tranzacției \"READ COMMITTED\". Acest lucru poate cauza probleme atunci când mai multe acțiuni sunt executate în paralel.",
     "Profile information" : "Informații de profil",
     "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Poza de profil, numele complet, adresa de e-mail, numărul de telefon, adresa, site-ul web, Twitter, organizația, rolul, titlul, biografia și dacă profilul dvs. este activat.",
     "Nextcloud settings" : "Setări Nextcloud",
+    "Enable" : "Activare",
     "Here you can decide which group can access certain sections of the administration settings." : "Aici puteți decide ce grup poate accesa anumite secțiuni din setările de administrare.",
-    "None" : "Niciuna",
     "Unable to modify setting" : "Nu se poate modifica setarea",
+    "None" : "Niciuna",
+    "Allow apps to use the Share API" : "Permite aplicațiilor să folosească API-ul de partajare",
+    "Allow resharing" : "Permite repartajarea",
+    "Allow sharing with groups" : "Permite partajarea cu grupuri",
+    "Allow public uploads" : "Permite încărcări publice",
+    "Enforce password protection" : "Impune protecția prin parolă",
+    "Enforce expiration date" : "Impune data de expirare",
     "Two-Factor Authentication" : " Autentificare în doi pași",
-    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Autentificarea cu doi factori poate fi impusă pentru toți utilizatorii și pentru grupuri specifice. Dacă aceștia nu au configurat un furnizor cu doi factori, nu se vor putea conecta la sistem.",
     "Enforce two-factor authentication" : "Forțează autentificarea cu doi factori",
     "Limit to groups" : "Limitează pentru grupuri",
     "Enforcement of two-factor authentication can be set for certain groups only." : "Forțarea autentificării cu doi factori poate fi setată doar pentru anumite grupuri.",
@@ -135,105 +130,131 @@ OC.L10N.register(
     "Two-factor authentication is not enforced for members of the following groups." : "Autentificarea cu doi factori nu este impusă pentru membrii următoarelor grupuri.",
     "Excluded groups" : "Grupuri excluse",
     "Save changes" : "Salvează modificările",
+    "Default" : "Implicită",
+    "Remove" : "Șterge",
+    "Featured" : "Recomandată",
+    "Icon" : "Pictogramă",
+    "Name" : "Nume",
+    "Version" : "Versiunea",
+    "Level" : "Nivel",
+    "Actions" : "Acțiuni",
+    "No apps found for your version" : "Nu au fost găsite aplicații pentru versiunea ta",
+    "Group name" : "Numele grupului",
+    "Type" : "Tip",
+    "Learn more" : "Află mai mult",
+    "Confirm" : "Confirmă",
+    "Cancel" : "Anulare",
+    "Description" : "Descriere",
+    "View in store" : "Vezi în magazin",
+    "Visit website" : "Viziteaza pagina web",
+    "Admin documentation" : "Documentație pentru administrare",
+    "Developer documentation" : "Documentație pentru dezvoltatori",
+    "Details" : "Detalii",
     "All" : "Toate ",
     "No results" : "Niciun rezultat",
     "Update to {version}" : "Actualizare la {version}",
-    "Remove" : "Șterge",
-    "Disable" : "Dezactivați",
-    "View in store" : "Vezi în magazin",
-    "Visit website" : "Viziteaza pagina web",
+    "Author" : "Autor",
+    "Categories" : "Categori",
+    "Resources" : "Resurse",
+    "Documentation" : "Documentație",
+    "Interact" : "Interacționați",
     "Report a bug" : "Raportează un defect",
-    "Admin documentation" : "Documentație pentru administrare",
-    "Developer documentation" : "Documentație pentru dezvoltatori",
-    "No apps found for your version" : "Nu au fost găsite aplicații pentru versiunea ta",
+    "Request feature" : "Solicitare funcționalități",
+    "Ask questions or discuss" : "Puneți întrebări sau participați la discuții",
+    "Changelog" : "Listă modificări",
+    "Google Chrome for Android" : "Google Chrome for Android",
+    "{productName} Android app" : "{productName} aplicație Android",
+    "This session" : "Această sesiune",
     "Device settings" : "Setările dispozitivului",
     "Allow filesystem access" : "Permite accesul la fișierele de sistem",
-    "Rename" : "Redenumește",
+    "Rename" : "Redenumire",
     "Revoke" : "Revocă",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
-    "Google Chrome for Android" : "Google Chrome for Android",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
-    "This session" : "Această sesiune",
     "Device" : "Dispozitiv",
     "Last activity" : "Ultima activitate",
     "Devices & sessions" : "Dispozitive și sesiuni",
     "Web, desktop and mobile clients currently logged in to your account." : "Clienții web, desktop și mobil conectați în prezent la contul dvs.",
-    "Do you really want to wipe your data from this device?" : "Chiar doriți să vă ștergeți datele de pe acest dispozitiv?",
-    "Confirm wipe" : "Confirmați ștergerea",
     "Error while creating device token" : "Eroare la crearea token-ului de dispozitiv",
-    "Error while updating device token scope" : "Eroare la actualizarea domeniului de aplicare a token-ului de dispozitiv",
-    "Error while updating device token name" : "Eroare la actualizarea numelui token-ului dispozitivului",
-    "Error while deleting the token" : "Eroare de ștergere token",
-    "Error while wiping the device with the token" : "Eroare la ștergerea dispozitivului cu token-ul",
     "App name" : "Numele aplicației",
     "Create new app password" : "Crează o nouă parolă pentru aplicație",
-    "Use the credentials below to configure your app or device." : "Utilizați acreditările de mai jos pentru a vă configura aplicația sau dispozitivul.",
-    "For security reasons this password will only be shown once." : "Din motive de securitate, această parolă va fi afișată doar o singură dată.",
-    "Username" : "Nume utilizator",
+    "Login" : "Autentificare",
     "Password" : "Parolă",
-    "Done" : "Realizat",
-    "Copied!" : "S-a copiat!",
-    "Copy" : "Copiază",
-    "Enable" : "Activare",
+    "Password confirmation is required" : "Confirmarea parolei este necesară",
     "Server-side encryption" : "Criptare la nivel de server",
     "Enable server-side encryption" : "Activează criptarea pe server",
+    "Select default encryption module:" : "Selectează modulul implicit de criptare:",
+    "Enable encryption" : "Activează criptarea",
     "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Criptarea, ca unică variantă, nu garantează securitatea sistemului. Consultați documentația pentru mai multe informații despre cum funcționează aplicația de criptare și variantele de utilizare acceptate.",
     "This is the final warning: Do you really want to enable encryption?" : "Aceasta este avertizarea finală: Chiar vrei să activezi criptarea?",
-    "Select default encryption module:" : "Selectează modulul implicit de criptare:",
+    "Submit" : "Trimite",
     "Current password" : "Parola curentă",
     "New password" : "Noua parolă",
-    "Change password" : "Schimbă parola",
-    "Cancel" : "Anulare",
-    "Details" : "Detalii",
-    "Your email address" : "Adresa ta de email",
     "No email address set" : "Fără adresă de email setată",
-    "Language" : "Limba",
     "Help translate" : "Ajută la traducere",
+    "Week starts on {firstDayOfWeek}" : "Săptămâna începe {firstDayOfWeek}",
     "Your phone number" : "Numărul tău de telefon",
     "Add" : "Adaugă",
+    "Create" : "Crează",
+    "Change" : "Schimbă",
+    "Delete" : "Șterge",
+    "Reshare" : "Redistribuiți",
     "Default language" : "Limba implicită",
     "Display name" : "Nume afișat",
     "Email" : "Email",
-    "Quota" : "Cotă",
+    "Quota" : "Procent",
+    "Language" : "Limba",
+    "Total rows summary" : "Rezumat total rânduri",
     "Avatar" : "Avatar",
-    "You do not have permissions to see the details of this user" : "Nu aveți permisiuni pentru a vedea detaliile acestui utilizator",
+    "Last login" : "Ultima autentificare",
     "{size} used" : "{size} folosită",
+    "Done" : "Realizat",
     "Edit" : "Editează",
     "Visibility" : "Vizibil",
-    "Show user backend" : "Arată administrare utilizator",
+    "Show last login" : "Arată ultima autentificare",
     "Send email" : "Expediază mesajul",
-    "Add WebAuthn device" : "Adăugați dispozitivul WebAuthn",
-    "Name your device" : "Numiți dispozitivul dvs.",
-    "Adding your device …" : "Adăugarea dispozitivului dvs ...",
     "Server error while trying to complete WebAuthn device registration" : "Eroare de server în timpul încercării de a finaliza înregistrarea dispozitivului WebAuthn",
+    "Add WebAuthn device" : "Adăugați dispozitivul WebAuthn",
     "Unnamed device" : "Dispozitiv fără nume",
     "Your browser does not support WebAuthn." : "Browserul dvs. nu acceptă WebAuthn.",
-    "Your apps" : "Aplicațiile tale",
-    "Add group" : "Adaugă grup",
+    "Security & setup warnings" : "Alerte de securitate & configurare",
+    "All checks passed." : "Toate verificările s-au terminat fără erori.",
+    "Apply" : "Aplică",
     "Admins" : "Administratori",
-    "Not saved" : "Nu a fost salvat",
     "Sending…" : "Se trimite...",
     "Email sent" : "Mesajul a fost expediat",
     "Location" : "Locație",
     "Profile picture" : "Imagine de profil",
     "About" : "Despre",
     "Full name" : "Nume complet",
+    "Headline" : "Titlu",
+    "Organisation" : "Organizație",
     "Phone number" : "Număr telefon",
     "Role" : "Rol",
-    "Twitter" : "Twitter",
     "Website" : "Site web",
+    "Private" : "Privat",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Vizibil doar pentru persoanele care se potrivesc prin integrarea numărului de telefon prin Talk pe mobil",
+    "Local" : "Local",
+    "Only visible to people on this instance and guests" : "Vizibil doar pentru persoanele din această instanță și pentru oaspeți",
+    "Federated" : "Federat",
+    "Only synchronize to trusted servers" : "Sincronizează doar cu serverele de încredere",
+    "Published" : "Publicat",
+    "Synchronize to trusted servers and the global and public address book" : "Sincronizarea cu serverele de încredere și cu cartea de adrese globală și publică",
+    "Your apps" : "Aplicațiile tale",
     "Disabled apps" : "Aplicații inactive",
     "Updates" : "Actualizări",
+    "Featured apps" : "Aplicații recomandate",
     "Hide" : "Ascunde",
+    "Disable" : "Dezactivați",
+    "Unknown" : "Necunoscut",
     "Never" : "Niciodată",
-    "Documentation" : "Documentație",
+    "Do you really want to wipe your data from this device?" : "Chiar doriți să vă ștergeți datele de pe acest dispozitiv?",
+    "Confirm wipe" : "Confirmați ștergerea",
+    "Error while wiping the device with the token" : "Eroare la ștergerea dispozitivului cu token-ul",
+    "Error while updating device token name" : "Eroare la actualizarea numelui token-ului dispozitivului",
+    "Error while updating device token scope" : "Eroare la actualizarea domeniului de aplicare a token-ului de dispozitiv",
+    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Prea multe cereri din această rețea. Încercați mai târziu sau contactați administratorul.",
+    "Error" : "Eroare",
     "Forum" : "Forum",
-    "Login" : "Autentificare",
+    "Legal notice" : "Aviz juridic",
     "SSL" : "SSL",
     "Open documentation" : "Deschide documentația",
     "Send mode" : "Modul de expediere",
@@ -244,29 +265,9 @@ OC.L10N.register(
     "Authentication" : "Autentificare",
     "Authentication required" : "Autentificare necesară",
     "Credentials" : "Detalii de autentificare",
-    "SMTP Username" : "Nume utilizator SMTP",
     "SMTP Password" : "Parolă SMTP",
     "Save" : "Salvează",
-    "All checks passed." : "Toate verificările s-au terminat fără erori.",
-    "Version" : "Versiunea",
-    "Allow apps to use the Share API" : "Permite aplicațiilor să folosească API-ul de partajare",
-    "Enforce expiration date" : "Impune data de expirare",
-    "Allow public uploads" : "Permite încărcări publice",
-    "Enforce password protection" : "Impune protecția prin parolă",
-    "Set default expiration date" : "Setează data implicită de expirare",
-    "Allow resharing" : "Permite repartajarea",
-    "Allow sharing with groups" : "Permite partajarea cu grupuri",
-    "Exclude groups from sharing" : "Exclude grupuri de la partajare",
-    "These groups will still be able to receive shares, but not to initiate them." : "Aceste grupuri vor putea în continuare să primească partajări, dar nu să le inițieze.",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Această versiune comunitară a Nextcloud nu este suportată, iar notificările instantanee nu sunt disponibile.",
-    "You created app password \"{token}\"" : "Ai creat parola aplicației \"{token}\"",
-    "An administrator created app password \"{token}\"" : "Un administrator a creat parola aplicației \"{token}\"",
-    "png or jpg, max. 20 MB" : "png sau jpg, max. 20 MB",
-    "Send email to new user" : "Trimite email către noul utilizator",
-    "Plain" : "Plain",
-    "NT LAN Manager" : "NT LAN Manager",
-    "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "STARTTLS",
-    "Authentication method" : "Modul de autentificare"
+    "Adding your device …" : "Adăugarea dispozitivului dvs ..."
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
